/**
 * Geocode Earth Autocomplete Element v0.7.0
 * Copyright (c) 2022 Cleared for Takeoff, Inc.
 *
 * @license MIT
 */
// src/index.js
import React3, { useMemo } from "react";
import ReactDOM from "react-dom";

// src/autocomplete/autocomplete.js
import React2, { useState, useCallback, useRef, useEffect } from "react";
import useDeepCompareEffect from "use-deep-compare-effect";
import { useCombobox } from "downshift";
import { createAutocomplete } from "@geocodeearth/core-js";
import throttle from "lodash.throttle";

// src/autocomplete/autocomplete.css
var autocomplete_default = '*{box-sizing:border-box}:host{all:initial;--gray-100: #F3F4F6;--gray-300: #D1D5DB;--gray-500: #6B7280;--gray-900: #111827;--blue-600: #3182CE;--border-radius: 5px;--font-family: ui-sans-serif, system-ui, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, "Noto Sans", sans-serif;--input-color: var(--gray-900);--input-bg: #fff;--input-border: 1px solid var(--gray-300);--input-height: 47px;--input-shadow: rgba(0, 0, 0, 0) 0px 0px 0px 0px, rgba(0, 0, 0, 0) 0px 0px 0px 0px, rgba(0, 0, 0, .05) 0px 1px 2px 0px;--search-icon-color: var(--gray-500);--search-icon-size: 20px;--loading-color: var(--gray-500);--loading-size: 31px;--results-spacing: 10px;--results-bg: #fff;--results-z-index: 10;--results-shadow: rgb(255, 255, 255) 0px 0px 0px 0px, rgba(0, 0, 0, .05) 0px 0px 0px 1px, rgba(0, 0, 0, .1) 0px 10px 15px -3px, rgba(0, 0, 0, .05) 0px 4px 6px -2px;--result-item-color: var(--gray-900);--result-item-border: 1px solid var(--gray-100);--result-item-active-color: var(--gray-900);--result-item-active-bg: var(--gray-100);--result-item-icon-color: var(--gray-500);--attribution-color: var(--gray-500);--attribution-color-hover: var(--blue-600);display:block}.autocomplete{position:relative;font-size:16px;font-family:var(--font-family)}.label{position:absolute;width:1px;height:1px;padding:0;margin:-1px;overflow:hidden;clip:rect(0,0,0,0);white-space:nowrap;border-width:0}.input{font-size:16px;font-family:var(--font-family);color:var(--input-color);background:var(--input-bg);height:var(--input-height);display:block;width:100%;border:var(--input-border);padding:13px calc(12px + var(--loading-size) + 12px) 13px calc(12px + var(--search-icon-size) + 9px);border-radius:var(--border-radius);appearance:none;-webkit-appearance:none;-moz-appearance:none;outline:none;box-shadow:var(--input-shadow)}.loading{position:absolute;right:12px;top:calc((var(--input-height) - var(--loading-size)) / 2);width:var(--loading-size);height:var(--loading-size);stroke:var(--loading-color)}.search-icon{position:absolute;color:var(--search-icon-color);left:12px;top:calc((var(--input-height) - var(--search-icon-size)) / 2);width:var(--search-icon-size);height:var(--search-icon-size)}.results{font-size:16px;position:absolute;top:calc(var(--input-height) + var(--results-spacing));left:0;margin:0;padding:0 0 35px;width:100%;list-style:none;border-radius:var(--border-radius);background:var(--results-bg);overflow:hidden;box-shadow:var(--results-shadow);z-index:var(--results-z-index)}.results-empty{display:none}.result-item{display:flex;align-items:center;padding:13px 12px;cursor:default;color:var(--result-item-color);border-bottom:var(--result-item-border)}.result-item-icon{color:var(--result-item-icon-color);margin-right:10px;width:20px;height:20px;flex:none}.result-item-active{color:var(--result-item-active-color);background-color:var(--result-item-active-bg)}.attribution{position:absolute;bottom:0;width:100%;padding:0 12px;height:35px;color:var(--attribution-color);line-height:35px;font-size:12px;text-align:right}.attribution a{color:var(--attribution-color);text-decoration:underline}.attribution a:hover{color:var(--attribution-color-hover)}';

// src/strings.js
var strings_default = {
  inputPlaceholder: "Search a city or address"
};

// src/icons.js
import React from "react";
var LocationMarker = ({ className }) => /* @__PURE__ */ React.createElement("svg", {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 20 20",
  fill: "currentColor",
  className
}, /* @__PURE__ */ React.createElement("path", {
  fillRule: "evenodd",
  d: "M5.05 4.05a7 7 0 119.9 9.9L10 18.9l-4.95-4.95a7 7 0 010-9.9zM10 11a2 2 0 100-4 2 2 0 000 4z",
  clipRule: "evenodd"
}));
var Search = ({ className }) => /* @__PURE__ */ React.createElement("svg", {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  stroke: "currentColor",
  fill: "none",
  className
}, /* @__PURE__ */ React.createElement("path", {
  strokeLinecap: "round",
  strokeLinejoin: "round",
  strokeWidth: 2,
  d: "M21 21l-6-6m2-5a7 7 0 11-14 0 7 7 0 0114 0z"
}));
var Loading = ({ className }) => /* @__PURE__ */ React.createElement("svg", {
  width: "44",
  height: "44",
  viewBox: "0 0 44 44",
  xmlns: "http://www.w3.org/2000/svg",
  stroke: "currentColor",
  className
}, /* @__PURE__ */ React.createElement("g", {
  fill: "none",
  fillRule: "evenodd",
  strokeWidth: "2"
}, /* @__PURE__ */ React.createElement("circle", {
  cx: "22",
  cy: "22",
  r: "1"
}, /* @__PURE__ */ React.createElement("animate", {
  attributeName: "r",
  begin: "0s",
  dur: "1.4s",
  values: "1; 20",
  calcMode: "spline",
  keyTimes: "0; 1",
  keySplines: "0.165, 0.84, 0.44, 1",
  repeatCount: "indefinite"
}), /* @__PURE__ */ React.createElement("animate", {
  attributeName: "stroke-opacity",
  begin: "0s",
  dur: "1.4s",
  values: "1; 0",
  calcMode: "spline",
  keyTimes: "0; 1",
  keySplines: "0.3, 0.61, 0.355, 1",
  repeatCount: "indefinite"
})), /* @__PURE__ */ React.createElement("circle", {
  cx: "22",
  cy: "22",
  r: "1"
}, /* @__PURE__ */ React.createElement("animate", {
  attributeName: "r",
  begin: "-0.7s",
  dur: "1.4s",
  values: "1; 20",
  calcMode: "spline",
  keyTimes: "0; 1",
  keySplines: "0.165, 0.84, 0.44, 1",
  repeatCount: "indefinite"
}), /* @__PURE__ */ React.createElement("animate", {
  attributeName: "stroke-opacity",
  begin: "-0.7s",
  dur: "1.4s",
  values: "1; 0",
  calcMode: "spline",
  keyTimes: "0; 1",
  keySplines: "0.3, 0.61, 0.355, 1",
  repeatCount: "indefinite"
}))));

// src/escape.js
import _escape from "lodash.escape";
var escape = (v) => {
  if (typeof v === "string")
    return _escape(v);
  if (typeof v === "number" || typeof v === "boolean")
    return v;
  if (Array.isArray(v))
    return v.map((l) => escape(l));
  return Object.keys(v).reduce((attrs, key) => ({
    ...attrs,
    [key]: escape(v[key])
  }), {});
};
var escape_default = escape;

// src/autocomplete/autocomplete.js
var emptyResults = {
  text: "",
  features: []
};
var autocomplete_default2 = ({
  apiKey,
  params,
  options,
  placeholder = strings_default.inputPlaceholder,
  value = "",
  autoFocus = false,
  throttle: throttleWait = 200,
  onSelect: userOnSelectItem,
  onChange: userOnChange,
  onFeatures: userOnFeatures,
  onError: userOnError,
  environment = window,
  rowTemplate,
  stringTemplate
}) => {
  const [results, setResults] = useState(emptyResults);
  const [isLoading, setIsLoading] = useState(false);
  const inputRef = useRef();
  const autocomplete = useRef();
  useEffect(() => {
    if (typeof userOnFeatures === "function") {
      userOnFeatures(results.features);
    }
  }, [results]);
  useDeepCompareEffect(() => {
    try {
      autocomplete.current = createAutocomplete(apiKey, params, {
        ...options,
        client: `ge-autocomplete${true ? `-${"0.7.0"}` : ""}`
      });
    } catch (err) {
      onError(err);
    }
  }, [apiKey, params, options]);
  const search = useCallback((text) => {
    autocomplete.current(text).then(({ features, discard }) => {
      setIsLoading(false);
      if (discard || inputRef.current.value !== text) {
        return;
      }
      setResults({ text, features });
      openMenu();
    }).catch(onError);
  }, [autocomplete]);
  const throttledSearch = useCallback(throttle(search, throttleWait, { leading: true, trailing: true }), [search]);
  const onInputValueChange = ({ type, inputValue }) => {
    const term = inputValue;
    if (typeof userOnChange === "function") {
      userOnChange(term);
    }
    if (term === "") {
      setIsLoading(false);
      setResults(emptyResults);
      return;
    }
    const searchOn = [
      useCombobox.stateChangeTypes.InputChange,
      useCombobox.stateChangeTypes.FunctionSetInputValue
    ];
    if (searchOn.includes(type)) {
      setIsLoading(true);
      throttledSearch(term);
    }
  };
  const onSelectItem = ({ selectedItem }) => {
    setResults(emptyResults);
    if (typeof userOnSelectItem === "function") {
      userOnSelectItem(selectedItem);
    }
  };
  const onError = (error) => {
    setIsLoading(false);
    if (typeof userOnError === "function") {
      userOnError(error);
    } else {
      console.error(error);
    }
  };
  const itemToString = (feature, extra) => {
    if (typeof stringTemplate === "function") {
      return stringTemplate({ feature, ...extra });
    }
    return feature.properties.label;
  };
  useEffect(() => {
    var _a;
    if (autoFocus === true) {
      (_a = inputRef.current) == null ? void 0 : _a.focus();
    }
  }, [autoFocus]);
  useEffect(() => setInputValue(value), [value]);
  const {
    isOpen,
    getLabelProps,
    getMenuProps,
    getInputProps,
    getComboboxProps,
    highlightedIndex,
    getItemProps,
    setInputValue,
    openMenu
  } = useCombobox({
    environment,
    itemToString,
    items: results.features,
    onInputValueChange,
    onSelectedItemChange: onSelectItem
  });
  const showResults = isOpen && results.features.length > 0;
  return /* @__PURE__ */ React2.createElement(React2.Fragment, null, /* @__PURE__ */ React2.createElement("style", null, autocomplete_default), /* @__PURE__ */ React2.createElement("div", {
    className: "autocomplete"
  }, /* @__PURE__ */ React2.createElement("label", {
    ...getLabelProps(),
    className: "label"
  }, placeholder), /* @__PURE__ */ React2.createElement("div", {
    ...getComboboxProps()
  }, /* @__PURE__ */ React2.createElement(Search, {
    className: "search-icon"
  }), /* @__PURE__ */ React2.createElement("input", {
    ...getInputProps({ ref: inputRef }),
    spellCheck: false,
    placeholder,
    className: "input"
  }), isLoading && /* @__PURE__ */ React2.createElement(Loading, {
    className: "loading"
  })), /* @__PURE__ */ React2.createElement("ol", {
    ...getMenuProps(),
    className: showResults ? "results" : "results-empty"
  }, showResults && results.features.map((item, index) => {
    if (typeof rowTemplate === "function") {
      return /* @__PURE__ */ React2.createElement("li", {
        key: item.properties.id,
        ...getItemProps({ item, index }),
        dangerouslySetInnerHTML: {
          __html: rowTemplate({
            feature: escape_default(item),
            active: highlightedIndex === index,
            searchTerm: inputRef.current.value,
            index
          })
        }
      });
    } else {
      return /* @__PURE__ */ React2.createElement("li", {
        className: highlightedIndex === index ? "result-item result-item-active" : "result-item",
        key: item.properties.id,
        ...getItemProps({ item, index })
      }, /* @__PURE__ */ React2.createElement(LocationMarker, {
        className: "result-item-icon"
      }), itemToString(item, {
        active: highlightedIndex === index,
        searchTerm: inputRef.current.value,
        index
      }));
    }
  }), /* @__PURE__ */ React2.createElement("div", {
    className: "attribution"
  }, "\xA9\xA0", /* @__PURE__ */ React2.createElement("a", {
    href: "https://geocode.earth"
  }, "Geocode Earth"), ",\xA0", /* @__PURE__ */ React2.createElement("a", {
    href: "https://openstreetmap.org/copyright"
  }, "OpenStreetMap"), ",\xA0and\xA0", /* @__PURE__ */ React2.createElement("a", {
    href: "https://geocode.earth/guidelines"
  }, "others"), "."))));
};

// src/compact.js
var compact_default = (obj) => {
  return Object.fromEntries(Object.entries(obj).filter(([_, v]) => {
    if (v === 0)
      return true;
    if (v && v.constructor === Object && Object.keys(v).length === 0)
      return false;
    return !!v;
  }));
};

// src/index.js
import _template from "lodash.template";
import _unescape from "lodash.unescape";
var customElementName = "ge-autocomplete";
var WebComponent = ({ host, ...autocompleteProps }) => {
  const environment = useMemo(() => {
    const doc = host.shadowRoot.ownerDocument;
    return {
      Node,
      document: doc,
      addEventListener: (name, cb) => doc.addEventListener.bind(host.shadowRoot)(name, cb, { passive: true }),
      removeEventListener: (name, cb) => doc.removeEventListener.bind(host.shadowRoot)(name, cb, { passive: true })
    };
  }, []);
  const dispatchEvent = (name, detail) => host.dispatchEvent(new CustomEvent(name, { detail }));
  const onSelect = (item) => dispatchEvent("select", item);
  const onFeatures = (items) => dispatchEvent("features", items);
  const onError = (error) => dispatchEvent("error", error);
  const onChange = (text) => {
    host.setAttribute("value", text);
    dispatchEvent("change", text);
  };
  return /* @__PURE__ */ React3.createElement(autocomplete_default2, {
    ...autocompleteProps,
    onSelect,
    onError,
    onChange,
    onFeatures,
    environment
  });
};
var GEAutocomplete = class extends HTMLElement {
  static get observedAttributes() {
    return [
      "api_key",
      "placeholder",
      "autofocus",
      "throttle",
      "lang",
      "size",
      "value",
      "layers",
      "sources",
      "boundary.country",
      "boundary.gid",
      "boundary.circle.lat",
      "boundary.circle.lon",
      "boundary.circle.radius",
      "boundary.rect.min_lat",
      "boundary.rect.max_lon",
      "boundary.rect.max_lat",
      "boundary.rect.min_lon",
      "focus.point.lat",
      "focus.point.lon"
    ];
  }
  get value() {
    var _a;
    return (_a = this.getAttribute("value")) == null ? void 0 : _a.trim();
  }
  set value(text) {
    this.setAttribute("value", text);
  }
  get props() {
    var _a, _b, _c;
    return compact_default({
      apiKey: (_a = this.getAttribute("api_key")) == null ? void 0 : _a.trim(),
      placeholder: this.getAttribute("placeholder"),
      autoFocus: this.getAttribute("autofocus") !== null,
      throttle: parseInt(this.getAttribute("throttle")),
      value: this.value,
      params: compact_default({
        lang: this.getAttribute("lang"),
        size: parseInt(this.getAttribute("size")),
        layers: (_b = this.getAttribute("layers")) == null ? void 0 : _b.split(",").map((l) => l.trim()),
        sources: (_c = this.getAttribute("sources")) == null ? void 0 : _c.split(",").map((l) => l.trim()),
        boundary: compact_default({
          country: this.getAttribute("boundary.country"),
          gid: this.getAttribute("boundary.gid"),
          circle: compact_default({
            lat: parseFloat(this.getAttribute("boundary.circle.lat")),
            lon: parseFloat(this.getAttribute("boundary.circle.lon")),
            radius: parseFloat(this.getAttribute("boundary.circle.radius"))
          }),
          rect: compact_default({
            minLon: parseFloat(this.getAttribute("boundary.circle.rect.min_lon")),
            maxLon: parseFloat(this.getAttribute("boundary.circle.rect.max_lon")),
            minLat: parseFloat(this.getAttribute("boundary.circle.rect.min_lat")),
            maxLat: parseFloat(this.getAttribute("boundary.circle.rect.max_lat"))
          })
        }),
        focusPoint: compact_default({
          lat: parseFloat(this.getAttribute("focus.point.lat")),
          lon: parseFloat(this.getAttribute("focus.point.lon"))
        })
      }),
      options: compact_default({
        host: this.getAttribute("__host")
      })
    });
  }
  constructor() {
    super();
    this.attachShadow({ mode: "open" });
  }
  connectedCallback() {
    this.importStyles();
    this.importTemplates();
    this.render();
  }
  importStyles() {
    const styles = this.querySelector("style");
    if (styles === null)
      return;
    this.shadowRoot.appendChild(styles);
  }
  importTemplates() {
    const templates = {
      stringTemplate: this.querySelector("template[string]"),
      rowTemplate: this.querySelector("template[row]")
    };
    Object.keys(templates).forEach((k) => {
      const tmpl = templates[k];
      if (tmpl === null)
        return;
      this[k] = _template(_unescape(tmpl.innerHTML.trim()), { variable: "item" });
      tmpl.remove();
    });
  }
  render() {
    ReactDOM.render(/* @__PURE__ */ React3.createElement(WebComponent, {
      ...this.props,
      host: this,
      stringTemplate: this.stringTemplate,
      rowTemplate: this.rowTemplate
    }), this.shadowRoot);
  }
  attributeChangedCallback(_, oldValue, newValue) {
    if (oldValue === newValue) {
      return;
    }
    this.render();
  }
};
if (window.customElements.get(customElementName) === void 0) {
  window.customElements.define(customElementName, GEAutocomplete);
}
var src_default = GEAutocomplete;
export {
  src_default as default
};
/**
 * Heroicons v1.0.0 (heroicons.com)
 * Copyright (c) 2020 Refactoring UI Inc.
 *
 * @license MIT
 */
/**
 * SVG Loaders (github.com/SamHerbert/SVG-Loaders)
 * Copyright (c) 2014 Sam Herbert
 *
 * @license MIT
 */
//# sourceMappingURL=index.js.map
